@@ -19,15 +19,15 @@
 #' atchashda <-
 #'     readAtcMapIntoHashMapDrugNamesAtcCodes(
 #'         system.file("extdata", "db-atc.map", package = "epos"), "\t")
-#' epso <- genDictListFromRawFreq(rawDrugNamesCoOcEpSO)
+#' epso <- rawDrugNamesCoOcEpSO
 #' neuroepso <- filterNeuroDrugs(epso, atchashda)
-#' esso <- genDictListFromRawFreq(rawDrugNamesCoOcESSO)
+#' esso <- rawDrugNamesCoOcESSO
 #' neuroesso   <- filterNeuroDrugs(esso, atchashda)
-#' epi <- genDictListFromRawFreq(rawDrugNamesCoOcEPILONT)
+#' epi <- rawDrugNamesCoOcEPILONT
 #' neuroepi    <- filterNeuroDrugs(epi, atchashda)
-#' episem <- genDictListFromRawFreq(rawDrugNamesCoOcEPISEM)
+#' episem <- rawDrugNamesCoOcEPISEM
 #' neuroepisem <- filterNeuroDrugs(episem, atchashda)
-#' fenics <- genDictListFromRawFreq(rawDrugNamesCoOcFENICS)
+#' fenics <- rawDrugNamesCoOcFENICS
 #' neurofenics <- filterNeuroDrugs(fenics, atchashda)
 #' mx <- max(
 #'     c(length(neuroepso), length(neuroesso), length(neuroepi),
@@ -38,7 +38,7 @@
 #'              EPILONT = c(neuroepi, rep("", (mx-length(neuroepi)))),
 #'              EPISEM = c(neuroepisem, rep("", (mx-length(neuroepisem)))),
 #'              FENICS = c(neurofenics, rep("", (mx-length(neurofenics)))))
-#' dneuromaxk <- TopKLists::calculate.maxK(dneuro, L=5, d=5, v=10)
+#' dneuromaxk <- TopKLists::calculate.maxK(dneuro, L=5, d=5, v=5)
 #' neurospace <- as.character(dneuromaxk$topkspace)
 #' dsepso <- calcDSEA(neuroepso, mx)
 #' dsesso <- calcDSEA(neuroesso, mx)
@@ -47,6 +47,11 @@
 #' dsfenics <- calcDSEA(neurofenics, mx)
 #' dsspace  <-  calcDSEA (neurospace, mx)
 #' p <- plotDSEA(dsepso, dsesso, dsepi, dsepisem, dsfenics, dsspace, dneuromaxk$maxK)
+#' \dontrun{
+#' ggplot2::ggsave("dsea.png", 
+#'    p <- plotDSEA(dsepso, dsesso, dsepi, dsepisem, dsfenics, dsspace, 
+#'    dneuromaxk$maxK), width=480, height=320, units = "mm", dpi = 300)
+#' }
 plotDSEA <- function (dsepso, dsesso, dsepi, dsepisem, dsfenics, dsspace, k) {
   topk <- max(
     c(length(dsepso), length(dsesso), length(dsepi),
@@ -66,11 +71,12 @@ plotDSEA <- function (dsepso, dsesso, dsepi, dsepisem, dsfenics, dsspace, k) {
                Final = c(dsspace, rep(max(dsspace), (topk-length(dsspace))))
     )
   
+  
   cols <-
-    c("EpSO" = "#FF0000",#red
-      "ESSO" = "#00FFFF",#cyan
-      "EPILONT" = "#9ACD32",#yellowgreen
-      "EPISEM" = "#0000FF",#blue
+    c("EpSO" = "#7800FE",#red
+      "ESSO" = "#00FFD6",#cyan
+      "EPILONT" = "#FFA501",#gold
+      "EPISEM" = "#E80908",#blue
       "FENICS" = "#008000",#green
       "Final" = "#FF00FF")#magenta
   
@@ -86,18 +92,18 @@ plotDSEA <- function (dsepso, dsesso, dsepi, dsepisem, dsfenics, dsspace, k) {
       panel.grid = ggplot2::element_line(colour = "grey",linetype = "F1"),
       panel.grid.major = ggplot2::element_line(colour = "grey",linetype = "F1"),
       panel.grid.minor.y = ggplot2::element_line(colour = "grey",linetype = "F1"),
-      legend.text = ggplot2::element_text(family="Times New Roman", size = 48, face = "italic"),
+      legend.text = ggplot2::element_text(family="Arial Nova Light", size = 24, face = "italic"),
       legend.background = ggplot2::element_rect(fill = "white"),
-      legend.position = c(0.45,0.82),
+      legend.position = c(0.654,0.85),
       legend.justification = c(0, 0),
       legend.key.size = ggplot2::unit(12, "mm"),
       legend.direction = "horizontal",
       legend.title = ggplot2::element_blank(),
-      plot.title = ggplot2::element_text(family="Times New Roman", size = 48, face = "plain"),
-      axis.title.x = ggplot2::element_text(family="Times New Roman", size = 48, face = "plain"),
-      axis.title.y = ggplot2::element_text(family="Times New Roman", size = 48, face = "plain"),
-      axis.text.x = ggplot2::element_text(family="Times New Roman", size = 48, face = "plain"),
-      axis.text.y = ggplot2::element_text(family="Times New Roman", size = 48, face = "plain")
+      plot.title = ggplot2::element_text(family="Arial Nova Light", size = 24, face = "plain"),
+      axis.title.x = ggplot2::element_text(family="Arial Nova Light", size = 24, face = "plain"),
+      axis.title.y = ggplot2::element_text(family="Arial Nova Light", size = 24, face = "plain"),
+      axis.text.x = ggplot2::element_text(family="Arial Nova Light", size = 24, face = "plain"),
+      axis.text.y = ggplot2::element_text(family="Arial Nova Light", size = 24, face = "plain")
     ) +
     ggplot2::labs (
       y = "Drug Set Enrichment Score",
@@ -106,7 +112,7 @@ plotDSEA <- function (dsepso, dsesso, dsepi, dsepisem, dsfenics, dsspace, k) {
       subtitle = ""
     ) +
     ggplot2::geom_step(
-      size = 4,
+      size = 2.7,
       linetype = 1
     ) +
     ggplot2::geom_step(
@@ -116,7 +122,7 @@ plotDSEA <- function (dsepso, dsesso, dsepi, dsepisem, dsfenics, dsspace, k) {
         y = "ESSO",
         colour = shQuote("ESSO")
       ),
-      size = 3,
+      size = 2.5,
       linetype = 1
     ) +
     ggplot2::geom_step(
@@ -126,7 +132,7 @@ plotDSEA <- function (dsepso, dsesso, dsepi, dsepisem, dsfenics, dsspace, k) {
         y = "EPILONT",
         colour = shQuote("EPILONT")
       ),
-      size = 3,
+      size = 2.5,
       linetype = 1
     ) +
     ggplot2::geom_step(
@@ -136,7 +142,7 @@ plotDSEA <- function (dsepso, dsesso, dsepi, dsepisem, dsfenics, dsspace, k) {
         y = "EPISEM",
         colour = shQuote("EPISEM")
       ),
-      size = 3,
+      size = 2,
       linetype = 1
     ) +
     ggplot2::geom_step(
@@ -159,11 +165,106 @@ plotDSEA <- function (dsepso, dsesso, dsepi, dsepisem, dsfenics, dsspace, k) {
       size = 2,
       linetype = 1
     ) +
-    ggplot2::coord_trans(xlim = c(1, 300), ylim = c(-5, 18)) +
-    ggplot2::scale_x_continuous(breaks = c(1, 50, 100, 150, 200, 250, 300)) +
-    ggplot2::scale_y_continuous(breaks = c(-5, 0, 5, 10, 15)) +
+    ggplot2::coord_trans(xlim = c(1, 225), ylim = c(-5, 10)) +
+    ggplot2::scale_x_continuous(breaks = c(0, 50, 100, 150, 200)) +
+    ggplot2::scale_y_continuous(breaks = c(-5, 0, 5, 10)) +
     ggplot2::scale_colour_manual(name = "Dictionary", values = cols) +
-    ggplot2::scale_size_manual()
+    ggplot2::scale_size_manual() +
+    ggplot2::annotate("segment", x = 35, 
+                      xend = which.max(dsepso), 
+                      y = 5.5, 
+                      yend = max(dsepso)+0.2, 
+                      colour = "#7800FE", 
+                      size=2, alpha=1, arrow=ggplot2::arrow()) + 
+    ggplot2::geom_text(data=(data.frame(x=35,y=6,label=
+      paste("max=(", 
+            which.max(dsepso), 
+            ",", 
+            round(max(dsepso),2),")",sep=""))), 
+      family="Arial Nova Light",
+      ggplot2::aes_string( x="x", y="y", label="label"), 
+      color="#000000", size=7 , angle=13, fontface="bold" ) +
+    ggplot2::annotate("segment", x = 160, 
+                      xend = (which.max(dsesso)+1), 
+                      y = 6, 
+                      yend = (max(dsesso)+0.1), 
+                      colour = "#00FFD6", 
+                      size=2, alpha=0.90, arrow=ggplot2::arrow()) + 
+    ggplot2::geom_text(data=
+                         (data.frame(
+                           x=160,
+                           y=6.5,label=paste("max=(", 
+                                                which.max(dsesso), 
+                                                ",", 
+                                                round(max(dsesso),2),")",sep=""))), 
+                       family="Arial Nova Light",
+                       ggplot2::aes_string( x="x", y="y", label="label"), 
+                       color="#000000", size=7 , angle=-10, fontface="bold" ) +
+    ggplot2::annotate("segment", 
+                      x = 125, 
+                      xend = which.max(dsepi)+1, 
+                      y = 8.5, 
+                      yend = max(dsepi)+0.1, 
+                      colour = "#FFA501", 
+                      size=2, alpha=0.75, arrow=ggplot2::arrow()) + 
+    ggplot2::geom_text(data=
+                         (data.frame(
+                           x=125,
+                           y=9,label=
+                                          paste("max=(", 
+                                                which.max(dsepi), 
+                                                ",", 
+                                                round(max(dsepi),2),")",sep=""))), 
+                       family="Arial Nova Light",
+                       ggplot2::aes_string( x="x", y="y", label="label"), 
+                       color="#000000", size=7 , angle=-5, fontface="bold" ) +
+    ggplot2::annotate("segment", x = 15, 
+                      xend = (which.max(dsfenics)-2), 
+                      y = 8, 
+                      yend = (max(dsfenics)+0.2), 
+                      colour = "#008000", 
+                      size=2, alpha=0.75, arrow=ggplot2::arrow()) + 
+    ggplot2::geom_text(data=(data.frame(x=15,y=8.5,label=
+                                          paste("max=(", 
+                                                which.max(dsfenics), 
+                                                ",", 
+                                                round(max(dsfenics),2),")",sep=""))),
+                       family="Arial Nova Light",
+                       ggplot2::aes_string( x="x", y="y", label="label"), 
+                       color="#000000", size=7 , angle=0, fontface="bold" )  +
+    ggplot2::annotate("segment", x = 90, 
+                      xend = (which.max(dsspace)), 
+                      y = 9, 
+                      yend = (max(dsspace)+0.1), 
+                      colour = "#FF00FF", 
+                      size=2, alpha=0.75, arrow=ggplot2::arrow()) + 
+    ggplot2::geom_text(data=(data.frame(x=90,
+                                        y=9.5,
+                                        label=
+                                          paste("max=(", 
+                                                which.max(dsspace), 
+                                                ",", 
+                                                round(max(dsspace),2),")",sep=""))),
+                       family="Arial Nova Light",
+                       ggplot2::aes_string( x="x", y="y", label="label"), 
+                       color="#000000", size=7 , angle=-3, fontface="bold" )  +
+    ggplot2::annotate("segment", x = 60, 
+                      xend = (which.max(dsepisem)+1), 
+                      y = 8, 
+                      yend = (max(dsepisem)+0.1), 
+                      colour = "#E80908", 
+                      size=2, alpha=0.75, arrow=ggplot2::arrow()) + 
+    ggplot2::geom_text(data=(data.frame(x=60,y=8.5,label=
+                                          paste("max=(", 
+                                                which.max(dsepisem), 
+                                                ",", 
+                                                round(max(dsepisem),2),")",sep=""))), 
+                       family="Arial Nova Light",
+                       ggplot2::aes_string( x="x", y="y", label="label"), 
+                       color="#000000", size=7 , angle=6, fontface="bold" )  
+  
+  
+  
   return (enrichmentplot)
 }
 
@@ -186,23 +287,17 @@ plotDSEA <- function (dsepso, dsesso, dsepi, dsepisem, dsfenics, dsspace, k) {
 #' utils::data(rawDrugNamesCoOcEPISEM, package="epos")
 #' utils::data(rawDrugNamesCoOcFENICS, package="epos")
 #' atchashda <-
-#' readAtcMapIntoHashMapDrugNamesAtcCodes(
-#'   system.file("extdata", "db-atc.map", package = "epos"), "\t")
-#' atchashaa <-
-#'   readAtcMapIntoHashMapAtcCodesAtcNames(
-#'     system.file("extdata", "db-atc.map", package = "epos"), "\t")
-#' atchashsec <-
-#'   readSecondLevelATC(
-#'     system.file("extdata", "atc-secondlevel.map", package = "epos"), "\t")
-#' epso <- genDictListFromRawFreq(rawDrugNamesCoOcEpSO)
+#'     readAtcMapIntoHashMapDrugNamesAtcCodes(
+#'         system.file("extdata", "db-atc.map", package = "epos"), "\t")
+#' epso <- rawDrugNamesCoOcEpSO
 #' neuroepso <- filterNeuroDrugs(epso, atchashda)
-#' esso <- genDictListFromRawFreq(rawDrugNamesCoOcESSO)
+#' esso <- rawDrugNamesCoOcESSO
 #' neuroesso   <- filterNeuroDrugs(esso, atchashda)
-#' epi <- genDictListFromRawFreq(rawDrugNamesCoOcEPILONT)
+#' epi <- rawDrugNamesCoOcEPILONT
 #' neuroepi    <- filterNeuroDrugs(epi, atchashda)
-#' episem <- genDictListFromRawFreq(rawDrugNamesCoOcEPISEM)
+#' episem <- rawDrugNamesCoOcEPISEM
 #' neuroepisem <- filterNeuroDrugs(episem, atchashda)
-#' fenics <- genDictListFromRawFreq(rawDrugNamesCoOcFENICS)
+#' fenics <- rawDrugNamesCoOcFENICS
 #' neurofenics <- filterNeuroDrugs(fenics, atchashda)
 #' mx <- max(
 #'     c(length(neuroepso), length(neuroesso), length(neuroepi),
@@ -213,7 +308,7 @@ plotDSEA <- function (dsepso, dsesso, dsepi, dsepisem, dsfenics, dsspace, k) {
 #'              EPILONT = c(neuroepi, rep("", (mx-length(neuroepi)))),
 #'              EPISEM = c(neuroepisem, rep("", (mx-length(neuroepisem)))),
 #'              FENICS = c(neurofenics, rep("", (mx-length(neurofenics)))))
-#' dneuromaxk <- TopKLists::calculate.maxK(dneuro, L=5, d=5, v=10)
+#' dneuromaxk <- TopKLists::calculate.maxK(dneuro, L=5, d=5, v=5)
 #' neurospace <- as.character(dneuromaxk$topkspace)
 #' enepso <- calcEnrichment(neuroepso)
 #' enesso <- calcEnrichment(neuroesso)
@@ -242,10 +337,10 @@ plotEnrichment <- function (enepso, enesso, enepi, enepisem, enfenics, enspace,
                )
   
   cols <-
-    c("EpSO" = "#FF0000",#red
-      "ESSO" = "#00FFFF",#cyan
-      "EPILONT" = "#9ACD32",#yellowgreen
-      "EPISEM" = "#0000FF",#blue
+    c("EpSO" = "#7800FE",#red
+      "ESSO" = "#00FFD6",#cyan
+      "EPILONT" = "#FFA501",#yellowgreen
+      "EPISEM" = "#E80908",#blue
       "FENICS" = "#008000",#green
       "Final" = "#FF00FF")#magenta
   
@@ -261,18 +356,18 @@ plotEnrichment <- function (enepso, enesso, enepi, enepisem, enfenics, enspace,
       panel.grid = ggplot2::element_line(colour = "grey",linetype = "F1"),
       panel.grid.major = ggplot2::element_line(colour = "grey",linetype = "F1"),
       panel.grid.minor.y = ggplot2::element_line(colour = "grey",linetype = "F1"),
-      legend.text = ggplot2::element_text(family="Times New Roman", size = 48, face = "italic"),
+      legend.text = ggplot2::element_text(family="Arial Nova Light", size = 48, face = "italic"),
       legend.background = ggplot2::element_rect(fill = "white"),
       legend.position = c(0.06,0.76),
       legend.justification = c(0, 0),
       legend.key.size = ggplot2::unit(12, "mm"),
       legend.direction = "horizontal",
       legend.title = ggplot2::element_blank(),
-      plot.title = ggplot2::element_text(family="Times New Roman", size = 48, face = "plain"),
-      axis.title.x = ggplot2::element_text(family="Times New Roman", size = 48, face = "plain"),
-      axis.title.y = ggplot2::element_text(family="Times New Roman", size = 48, face = "plain"),
-      axis.text.x = ggplot2::element_text(family="Times New Roman", size = 48, face = "plain"),
-      axis.text.y = ggplot2::element_text(family="Times New Roman", size = 48, face = "plain")
+      plot.title = ggplot2::element_text(family="Arial Nova Light", size = 48, face = "plain"),
+      axis.title.x = ggplot2::element_text(family="Arial Nova Light", size = 48, face = "plain"),
+      axis.title.y = ggplot2::element_text(family="Arial Nova Light", size = 48, face = "plain"),
+      axis.text.x = ggplot2::element_text(family="Arial Nova Light", size = 48, face = "plain"),
+      axis.text.y = ggplot2::element_text(family="Arial Nova Light", size = 48, face = "plain")
     ) +
     ggplot2::labs (
       y = "# of Reference Drugs",
@@ -350,6 +445,52 @@ plotEnrichment <- function (enepso, enesso, enepi, enepisem, enfenics, enspace,
 #' @examples
 #' d <- getRefAll()
 getRefAll <- function () {
+  n03 <- c(
+    "Barbexaclone",
+    "Beclamide",
+    "Brivaracetam",
+    "Cannabidiol",
+    "Carbamazepine",
+    "Carisbamate",
+    "Clonazepam",
+    "Eslicarbazepine",
+    "Ethadione",
+    "Ethosuximide",
+    "Ethotoin",
+    "Ezogabine",
+    "Felbamate",
+    "Fosphenytoin",
+    "Gabapentin",
+    "Lacosamide",
+    "Lamotrigine",
+    "Levetiracetam",
+    "Mephenytoin",
+    "Metharbital",
+    "Methsuximide",
+    "Neocitrullamon",
+    "Oxcarbazepine",
+    "Paramethadione",
+    "Perampanel",
+    "Phenacemide",
+    "Pheneturide",
+    "Phenobarbital",
+    "Phensuximide",
+    "Phenytoin",
+    "Pregabalin",
+    "Primidone",
+    "Progabide",
+    "Rufinamide",
+    "Stiripentol",
+    "Sulthiame",
+    "Tiagabine",
+    "Topiramate",
+    "Trimethadione",
+    "Valproic acid",
+    "Valpromide",
+    "Vigabatrin"
+  )
+  
+  
   broadspectrum <- c(             
     "Brivaracetam",
     "Clobazam",
@@ -444,7 +585,17 @@ getRefAll <- function () {
     "Zonisamide"
   )
   
-  refall <- union (seizuremed, union (drugse, union (seizuremed, up2date)))
+  refall <- union (
+    seizuremed, 
+    union (drugse, 
+           union (
+             seizuremed, 
+             union (up2date, 
+                    n03
+        )
+      )
+    )
+  )
   
   return (refall)
 }
@@ -496,17 +647,11 @@ calcDSEA <- function (alist, N) {
   counter <- 0
   for (drug in alist) {
     enrichment <- c(enrichment, curscore)
-    # print(cat("enrichment: ", enrichment))
     counter <- (counter + 1)
-    # print(cat("counter: ", counter))
-    divisor_hit  <- (S - (max (enrichment)-1))
-    # print(cat("divisor_hit: ", divisor_hit))
-    divisor_miss <- (N - (max (enrichment)-1))
-    # print(cat("divisor_miss: ", divisor_miss))
+    divisor_hit  <- (S - curscore)
+    divisor_miss <- (N - curscore)
     p_hit <-  log((curscore+S)/divisor_hit)
-    # print(cat("p_hit: ", p_hit))
     p_miss <- -log((curscore+N)/divisor_miss)
-    # print(cat("p_miss: ", p_miss))
     if (drug %in% refall) {
       curscore <- curscore +1
       ea <- c(ea, (utils::tail(ea, n=1) + p_hit))
@@ -515,4 +660,4 @@ calcDSEA <- function (alist, N) {
     }
   }
   return (ea)
-}
\ No newline at end of file
+}
